# Generated by Django 5.2.7 on 2025-11-21 15:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='requirementset',
            name='depends_on',
            field=models.ManyToManyField(blank=True, help_text="Andere RequirementSets, die zuerst erfüllt sein müssen, bevor dieses Set geprüft wird ('after').", related_name='dependents', to='endoreg_db.requirementset'),
        ),
    ]
