# Generated by Django 5.2.7 on 2025-11-16 16:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0008_remove_event_event_classification_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='modelmeta',
            options={'ordering': ['-date_created'], 'verbose_name': 'Model Metadata', 'verbose_name_plural': 'Model Metadata'},
        ),
        migrations.AlterUniqueTogether(
            name='modelmeta',
            unique_together={('name', 'version', 'model')},
        ),
    ]
