# Generated by Django 5.2.7 on 2025-11-10 16:54

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0003_add_center_display_name'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='casetemplate',
            name='rules',
        ),
        migrations.RemoveField(
            model_name='casetemplate',
            name='secondary_rules',
        ),
        migrations.RemoveField(
            model_name='casetemplate',
            name='template_type',
        ),
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='chained_rules',
        ),
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='date_value_distribution',
        ),
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='multiple_categorical_value_distribution',
        ),
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='numerical_value_distribution',
        ),
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='rule_type',
        ),
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='single_categorical_value_distribution',
        ),
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='value_type',
        ),
        migrations.DeleteModel(
            name='CaseTemplateRuleValue',
        ),
        migrations.AlterField(
            model_name='modelmeta',
            name='weights',
            field=models.FileField(blank=True, help_text='Path to the model weights file (.safetensors), relative to MEDIA_ROOT.', null=True, upload_to='model_weights', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['safetensors', 'pth', 'pt'])]),
        ),
        migrations.DeleteModel(
            name='CaseTemplate',
        ),
        migrations.DeleteModel(
            name='CaseTemplateType',
        ),
        migrations.DeleteModel(
            name='CaseTemplateRuleType',
        ),
        migrations.DeleteModel(
            name='CaseTemplateRule',
        ),
        migrations.DeleteModel(
            name='CaseTemplateRuleValueType',
        ),
    ]
