# Generated by Django 5.2.7 on 2025-11-11 09:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0004_employee_city_employee_post_code_employee_street_and_more'),
        ('endoreg_db', '0004_remove_casetemplate_rules_and_more'),
    ]

    operations = [
    ]
